JSDoc: Global

# Global

##

### Methods

#### getGeometry(shapeName, ranges) → {THREE.Geometry}

Return a correctly sized geometry that matches the plotting space

##### Parameters:

Name | Type | Description
--- | --- | ---
`shapeName` | string | One of 'Sphere', 'Cube', 'Cone', 'Icosahedron' or 'Cylinder'.
`ranges` | Object | Object with two arrays of "max" and "min" values as generated by the `DecompositionModel` dimensionRanges property

Source:
  - shapes.js, line 11

##### Returns:

The requested geometry object with a size appropriate for the data presented on screen.

Type
  THREE.Geometry